;;; 50weblint-el.el -- debian emacs setups for weblint-el.

;; Copyright 2014 Kevin Ryde

;; This file is part of weblint-el.
;;
;; weblint-el is free software; you can redistribute it and/or modify it under
;; the terms of the GNU General Public License as published by the Free
;; Software Foundation; either version 3, or (at your option) any later
;; version.
;;
;; weblint-el is distributed in the hope that it will be useful, but WITHOUT
;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
;; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
;; more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

(let ((dir (concat "/usr/share/"
                   (symbol-name debian-emacs-flavor)
                   "/site-lisp/weblint-el")))

  (cond ((not (file-exists-p "/usr/share/emacs/site-lisp/weblint-el/weblint.el"))
         (message "weblint-el removed but not purged, skipping setup"))

        ((not (file-exists-p (expand-file-name "weblint.el" dir)))
         ;; autoloads not available until install script succeeds, ignore
         ;; until then for the benefit of other byte compiling, such as
         ;; emacsen-common compiling 00debian-vars.el
         (message "weblint-el not yet byte-compiled, skipping setup"))

        (t
         ;; debian-pkg-add-load-path-item as from debian 3.1 "sarge",
         ;; emacsen-common 1.4.14 of June 2002
         (debian-pkg-add-load-path-item dir)

         (autoload 'weblint "weblint"
           "Run the \"weblint\" program on the current buffer file." t)
         (autoload 'weblint-after-save-setup "weblint"
           "Setup to run weblint on the current buffer when saved.")
         (custom-add-option 'html-mode-hook 'weblint-after-save-setup)

         ;; compilation-weblint.el not needed in GNU Emacs 23 up.
         ;; Needed in XEmacs 21.
         (if (< emacs-major-version 23)
             (eval-after-load "compile" '(require 'compilation-weblint))))))
